@@ -252,7 +252,7 @@ try:
        ("PyQt5.QtOpenGL") in sys.modules:
         OBJECT3D = True
 except:
-    _logger.debug("pyopengl not installed")
+    _logger.info("pyopengl not installed")
     OBJECT3D = False
 
 
@@ -265,15 +265,15 @@ except ImportError:
 
 if isSilxGLAvailable:
     SceneGLWindow = PyMca5.PyMcaGui.pymca.SilxGLWindow
-    try:
-        from PyMca5.PyMcaGui.pymca import SilxScatterWindow
-    except:
-        _logger.info("Cannot import SilxScatterWindow")
-
 elif OBJECT3D:
     SceneGLWindow = PyMcaGLWindow
 
-_logger.debug("SilxGL availability: %s", isSilxGLAvailable)
+try:
+    from PyMca5.PyMcaGui.pymca import SilxScatterWindow
+except:
+    _logger.info("Cannot import SilxScatterWindow")
+
+_logger.info("SilxGL availability: %s", isSilxGLAvailable)
 
 # check that OpenGL is actually supported (ESRF rnice problems)
 OPENGL_DRIVERS_OK = True
@@ -367,6 +367,8 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                 self.mainTabWidget = qt.QTabWidget(self.mdi)
                 self.mainTabWidget.setWindowTitle("Main Window")
                 self.mcaWindow = McaWindow.McaWindow(backend=backend)
+                self.mcaWindow.showRoiWidget(qt.Qt.BottomDockWidgetArea)
+
                 self.scanWindow = ScanWindow.ScanWindow(info=True,
                                                         backend=backend)
                 self.scanWindow._togglePointsSignal()
@@ -1057,13 +1059,14 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
             self.actionOpen = qt.QAction(self)
             self.actionOpen.setText(QString("&Open"))
             self.actionOpen.setIcon(self.Icons["fileopen"])
-            self.actionOpen.setShortcut(qt.Qt.CTRL+qt.Qt.Key_O)
+            self.actionOpen.setShortcut(qt.QKeySequence(qt.Qt.CTRL+qt.Qt.Key_O))
             self.actionOpen.triggered[bool].connect(self.onOpen)
             #filesaveas
             self.actionSaveAs = qt.QAction(self)
             self.actionSaveAs.setText(QString("&Save"))
             self.actionSaveAs.setIcon(self.Icons["filesave"])
-            self.actionSaveAs.setShortcut(qt.Qt.CTRL+qt.Qt.Key_S)
+            self.actionSaveAs.setShortcut(\
+                qt.QKeySequence(qt.Qt.CTRL+qt.Qt.Key_S))
             self.actionSaveAs.triggered[bool].connect(self.onSaveAs)
 
             #filesave
@@ -1077,14 +1080,16 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
             self.actionPrint = qt.QAction(self)
             self.actionPrint.setText(QString("&Print"))
             self.actionPrint.setIcon(self.Icons["fileprint"])
-            self.actionPrint.setShortcut(qt.Qt.CTRL+qt.Qt.Key_P)
+            self.actionPrint.setShortcut(\
+                qt.QKeySequence(qt.Qt.CTRL+qt.Qt.Key_P))
             self.actionPrint.triggered[bool].connect(self.onPrint)
 
             #filequit
             self.actionQuit = qt.QAction(self)
             self.actionQuit.setText(QString("&Quit"))
             #self.actionQuit.setIcon(self.Icons["fileprint"])
-            self.actionQuit.setShortcut(qt.Qt.CTRL+qt.Qt.Key_Q)
+            self.actionQuit.setShortcut(\
+                                       qt.QKeySequence(qt.Qt.CTRL+qt.Qt.Key_Q))
             qApp = qt.QApplication.instance()
             self.actionQuit.triggered.connect(qApp.closeAllWindows)
 
@@ -1750,7 +1755,8 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
         self.changeLog.show()
 
     def onDebug(self):
-        _logger.debug("Module name PyQt  %s", qt.PYQT_VERSION_STR)
+        if "PyQt5.QtCore" in sys.modules:
+            _logger.debug("Module name PyQt  %s", qt.PYQT_VERSION_STR)
         for module in sys.modules.values():
             try:
                 if 'Revision' in module.__revision__:
